@@ -17,6 +17,9 @@ model_parameters.glimML <- function(model,
                                     standardize = NULL,
                                     exponentiate = FALSE,
                                     p_adjust = NULL,
+                                    summary = getOption("parameters_summary", FALSE),
+                                    keep = NULL,
+                                    drop = NULL,
                                     verbose = TRUE,
                                     ...) {
   component <- match.arg(component)
@@ -41,6 +44,9 @@ model_parameters.glimML <- function(model,
     standardize = standardize,
     exponentiate = exponentiate,
     p_adjust = p_adjust,
+    keep_parameters = keep,
+    drop_parameters = drop,
+    summary = summary,
     verbose = verbose,
     ...
   )
