@@ -33,11 +33,12 @@ p_value.ivFixed <- function(model, method = "wald", ...) {
 }
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.ivFixed <- function(model,
                                      ci = 0.95,
                                      ci_method = "wald",
+                                     keep = NULL,
+                                     drop = NULL,
                                      verbose = TRUE,
                                      ...) {
   out <- .model_parameters_generic(
@@ -45,6 +46,8 @@ model_parameters.ivFixed <- function(model,
     ci = ci,
     ci_method = ci_method,
     merge_by = "Parameter",
+    keep_parameters = keep,
+    drop_parameters = drop,
     verbose = verbose,
     ...
   )
